multiplier_weights_cpp: Fast multiplier bootstrap weights

View source: R/RcppExports.R

multiplier_weights_cppR Documentation

Fast multiplier bootstrap weights

Description

Generates exponential multiplier weights for the wild/multiplier bootstrap used in nonlinear DiD inference.

Usage

multiplier_weights_cpp(n, nboot)

Arguments

n

Integer. Number of units.

nboot

Integer. Number of bootstrap iterations.

Value

A matrix of dimension n x nboot with positive weights that sum to n in each column.


NonlinearDiD documentation built on May 6, 2026, 1:06 a.m.