| multiplier_weights_cpp | R Documentation |
Generates exponential multiplier weights for the wild/multiplier bootstrap used in nonlinear DiD inference.
multiplier_weights_cpp(n, nboot)
n |
Integer. Number of units. |
nboot |
Integer. Number of bootstrap iterations. |
A matrix of dimension n x nboot with positive weights that sum to n in each column.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.