Learn R Programming

NonlinearDiD (version 0.1.0)

multiplier_weights_cpp: Fast multiplier bootstrap weights

Description

Generates exponential multiplier weights for the wild/multiplier bootstrap used in nonlinear DiD inference.

Usage

multiplier_weights_cpp(n, nboot)

Value

A matrix of dimension n x nboot with positive weights that sum to n in each column.

Arguments

n

Integer. Number of units.

nboot

Integer. Number of bootstrap iterations.